# [WIP] AnySchedule

***Still works in progress, no document, usage method are provided until first fully workalbe API get finished***

A composer tool for custom complex scheduler. (Such as WSD lr scheduler or more)

It is designed for scheduler for all hyperparameter in optimizer. (So schedule for weight decay or more hyper parameters is possible)

## Example

A simple example of "Multi-WSD" lr scheduler

| ![1737822139812](image/README/1737822139812.png) | ![1737822145021](image/README/1737822145021.png) |
| ---------------------------------------------- | ---------------------------------------------- |
